# 365scores
![python_version](https://img.shields.io/static/v1?label=Python&message=3.5%20|%203.6%20|%203.7&color=blue) [![PyPI downloads/month](https://img.shields.io/pypi/dm/365scores?logo=pypi&logoColor=white)](https://pypi.python.org/pypi/365scores)

## Description


## Install
~~~~bash
pip install 365scores
# or
pip3 install 365scores
~~~~